#!/bin/bash
set -o errexit
set -o nounset
set -o pipefail

cd $WORKSPACE
echo "Info: Java version"
echo "----------------------------------------------------"
$JAVA_HOME/bin/java -version
echo "----------------------------------------------------"
echo "Downloading Maven $MVN_VERSION from $MVN_URL"
wget -q $MVN_URL && unzip -qq apache-maven-${MVN_VERSION}-bin.zip
echo "Info: Maven version"
echo "----------------------------------------------------"
$MVN -version
echo "----------------------------------------------------"
echo "Downloading ONAP Maven XML for build process from oparent repo"
echo "----------------------------------------------------"
git clone "https://git.onap.org/oparent" $WORKSPACE/oparent
cd $WORKSPACE/oparent
# Check if a commitid parameter is given to specify a version of
# oparent repository to checkout. If commitid is not provided, the
# latest master version is used as default for backward
# compatibility for existing ONAP jobs.
set +o nounset
if [[ -v ${MVN_SETTINGS_XML_VERSION} ]]; then
  git checkout "${MVN_SETTINGS_XML_VERSION}"
fi
set -o nounset

# if MVN_PARAMS set then use them otherwise default to ""
LOCAL_MVN_PARAMS=""
set +o nounset
if [[ -n ${MVN_PARAMS} ]]; then
  LOCAL_MVN_PARAMS=${MVN_PARAMS}
fi
set -o nounset

# Copy Onap maven settings.xml to Jenkins home directory
if [ ! -d /home/jenkins/.m2 ]; then
  mkdir -p /home/jenkins/.m2/
fi
cp settings.xml /home/jenkins/.m2/settings.xml
cd $WORKSPACE
echo "----------------------------------------------------"
echo "Proceeding with unit test"
echo "----------------------------------------------------"
$MVN clean install -B -Dorg.slf4j.simpleLogger.log.org.apache.maven.cli.transfer.Slf4jMavenTransferListener=warn $LOCAL_MVN_PARAMS
